@@ -25,6 +25,8 @@ class BitwiseDays:
   WEEKENDS = SUNDAY + SATURDAY
 
   def __init__(self,raw_value=0):
+    if isinstance(raw_value,list):
+      raw_value = sum(raw_value)
     self.raw_value = raw_value
 
   def __unicode__(self):
@@ -42,6 +44,15 @@ class BitwiseDays:
 
       return string.join(days,",")
 
+  @property
+  def values_list(self):
+    days = []
+    for raw_value,short_name,long_name in BitwiseDays.CHOICES:
+      if raw_value & self.raw_value:
+        days.append(raw_value)
+
+    return days
+
   def included(self,raw_value):
     return self.raw_value & raw_value
 
